@@ -31,7 +31,7 @@ async fn incoming_ops_to_limbo() {
         let env = env.clone();
         all.push(tokio::task::spawn(async move {
             let start = std::time::Instant::now();
-            incoming_dht_ops_workflow(&env, sys_validation_trigger, vec![op], false)
+            incoming_dht_ops_workflow(&env, None, sys_validation_trigger, vec![op], false)
                 .await
                 .unwrap();
             println!("IN OP in {} s", start.elapsed().as_secs_f64());
